.. image:: https://travis-ci.org/Team4819/Yeti.svg?branch=master
    :target: https://travis-ci.org/Team4819/Yeti
.. image:: https://coveralls.io/repos/Team4819/Yeti/badge.png?branch=master
  :target: https://coveralls.io/r/Team4819/Yeti?branch=master

Yeti
====

Yeti is a Python runtime framework, designed for use on FIRST Robotics Competition Robots.
It allows you to easily build modularized robot programs, with mechanisms to allow for rapid
development and in-game failure recovery.

Documentation
=============

All Yeti documentation can be found at http://yeti-robotics-runtime.readthedocs.org

Examples
========
Aside from the example application found in this repository, you can see real robot code in
Team 4819's 2015 Python Codebase, found here: https://github.com/Team4819/2015-Python-Codebase

License
=======

See LICENSE.txt

Authors
=======

Christian Balcom (robot.inventor@gmail.com, FRC Team 4819)

